import java.io.Serializable;
import java.util.Random;
import java.util.UUID;

import com.hazelcast.core.Hazelcast;
import com.hazelcast.core.IMap;
import com.hazelcast.query.EntryObject;
import com.hazelcast.query.Predicate;
import com.hazelcast.query.PredicateBuilder;

public class Demo {

	public static void main(String[] args) throws Exception {

		IMap<String, Blob> blobs = Hazelcast.getMap("blobs");
		
		String name = null;
		for (int i = 0; i < 10; i++) {
			name = UUID.randomUUID().toString();
			blobs.put(name, new Blob(name));
		}
		
		int errorCount = 0;
		Random random = new Random();
		System.out.println("*************** RUNNING ****************");
		while(errorCount < 100) {
			long now = System.currentTimeMillis();
			
			Blob b = blobs.get(name);
			b.setLastUpdateTime(now);
			blobs.put(name,b);
			
			Thread.sleep(random.nextInt(100) + 1);
			
			EntryObject e = new PredicateBuilder().getEntryObject();
			Predicate<?,?> predicate = e.get("name").equal(name);
			long queryTime = blobs.values(predicate).iterator().next().getLastUpdateTime();
			long getTime = blobs.get(name).getLastUpdateTime();

			if (queryTime != getTime) {
				System.out.println("ERROR! Expected " + getTime + " Got " + queryTime);
				errorCount++;
			}
		}
		System.exit(errorCount);
		
	}
}

class Blob implements Serializable {
	private static final long serialVersionUID = 1L;
	private String name;
	private long lastUpdateTime;
	
	public Blob(String name) {
		this.name = name;
		this.lastUpdateTime = System.currentTimeMillis();
	}
	
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public long getLastUpdateTime() {
		return lastUpdateTime;
	}
	public void setLastUpdateTime(long lastUpdateTime) {
		this.lastUpdateTime = lastUpdateTime;
	}
}
